#include "stssettings.h"

#include <QRegularExpression>


StsSettings::StsSettings(const QString& path, const QString& dName, const QString& separator) :
    m_settings(path, QSettings::IniFormat),
    m_dName(dName),
    m_separator(separator)
{
    m_settings.beginGroup("PrevUser");
}

StsSettings::~StsSettings()
{
}

const UserStsData StsSettings::getPrevUserData() const
{
    UserStsData data;

    const auto text = m_settings.value(m_dName, QString()).toString();
    const auto match = QRegularExpression("(?P<username>.*?)@(?P<domain>.*)").match(text);
    if (match.hasMatch()) {
        data.username = match.captured("username");
        data.domain = match.captured("domain");
    } else {
        data.username = text;
    }

    return data;
}

void StsSettings::savePrevUserData(const UserStsData& data)
{
    if (!data.domain.isEmpty() && !m_separator.isEmpty()) {
        m_settings.setValue(m_dName, data.username + m_separator + data.domain);
    } else {
        m_settings.setValue(m_dName, data.username);
    }

    m_settings.sync();
}
